QuDataOutput - Qudas 0.1.1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# QuDataOutput

量子デバイスへの出力データを変換するクラスです。

class qudas.qudata.QuDataOutput(result: Dict[str, Any] | None = None, result_type: str | None = None)

  Bases: `QuDataBase`

  __abstractmethods__ = frozenset({})
  __init__(result: Dict[str, Any] | None = None, result_type: str | None = None)

    初期データとして出力データを受け取るクラス。

    Parameters:

      - result (dict, optional) – 計算結果データ。デフォルトはNone。

      - result_type (str, optional) – 結果の形式。デフォルトはNone。

  __module__ = 'qudas.qudata.qudata_output'
  from_amplify(result: Result) → QuDataOutput
  from_dimod(result: SampleSet) → QuDataOutput
  from_pulp(problem: LpProblem) → QuDataOutput
  from_scipy(result: OptimizeResult) → QuDataOutput
  to_dimod() → SampleSet
  to_scipy() → OptimizeResult